﻿using UnityEngine;
using System.Collections.Generic;

[System.Serializable]
public class CellMessage
{
	public bool bUnread = true;
	public bool bResponded = false;
	public string sender = "Person";
	public string contents = "";

	public List<string> responses = new List<string>();
}

public class Cellphone : MonoBehaviour
{
	public bool bShowPhoneUI = false;

	public List<CellMessage> messages = new List<CellMessage>();
	CellMessage activeMessage = null;

	Vector2 msgListScrollPos = Vector2.zero;

	GUIStyle cellOptionStyle = null;
	GUIStyle cellContentStyle = null;
	GUIStyle cellCloseButtStyle = null;

	enum MenuState
	{
		MessageCount,
		MessageList,
		MessageContents,
		Response,
		ResponseSent,
	}

	MenuState cellState = MenuState.MessageCount;

	void Start()
	{
//		bShowPhoneUI = true;
		cellOptionStyle = GameManager.MorningSkin.GetStyle("CellphoneOption");
		cellContentStyle = GameManager.MorningSkin.GetStyle("CellphoneText");
		cellCloseButtStyle = GameManager.MorningSkin.GetStyle("CellphoneCloseButt");
	}

	void OnGUI()
	{
		if (bShowPhoneUI)
		{
			float phoneWidth = 400f / (float)Screen.width;
			float phoneHeight = 400f / (float)Screen.height;
			Vector3 origin = Camera.main.ViewportToScreenPoint(new Vector3(0.5f - (phoneWidth * 0.5f), 0.5f - (phoneHeight * 0.5f)));
			Vector3 extent = Camera.main.ViewportToScreenPoint(new Vector3(phoneWidth, phoneHeight));

			GUILayout.BeginArea(new Rect(origin.x, origin.y, extent.x, extent.y), GameManager.MorningSkin.GetStyle("CellphoneBG"));

			if (cellState == MenuState.MessageCount)
			{
				DoHeader("You have " + NumUnreadMessages().ToString() + " unread messages.");

				GUILayout.BeginVertical();
				{
					GUILayout.FlexibleSpace();
					GUILayout.BeginHorizontal();
					{
						GUILayout.FlexibleSpace();

						if (GUILayout.Button("Check Messages", cellOptionStyle))
						{
							cellState = MenuState.MessageList;
						}
					}
					GUILayout.EndHorizontal();
				}
				GUILayout.EndVertical();
			}
			else if (cellState == MenuState.MessageList)
			{
				DoHeader("Unread messages:");

				msgListScrollPos = GUILayout.BeginScrollView(msgListScrollPos);
				foreach (CellMessage msg in messages)
				{
					if (msg.bUnread)
					{
						if (GUILayout.Button("-> From \"" + msg.sender + "\"", cellOptionStyle))
						{
							activeMessage = msg;
							activeMessage.bUnread = false;

							cellState = MenuState.MessageContents;
						}

						GUILayout.Space(5f);
					}
				}

				GUILayout.Space(24f);
				GUILayout.Label("Read messages:", cellContentStyle);
				GUILayout.Space(24f);

				foreach (CellMessage msg in messages)
				{
					if (!msg.bUnread)
					{
						if (GUILayout.Button("-> From \"" + msg.sender + "\"", cellOptionStyle))
						{
							activeMessage = msg;
							
							cellState = MenuState.MessageContents;
						}

						GUILayout.Space(5f);
					}
				}

				GUILayout.EndScrollView();
			}
			else if (cellState == MenuState.MessageContents)
			{
				// End the header.
				DoHeader("Message from \"" + activeMessage.sender + "\":");

				GUILayout.Space(24f);

				GUILayout.TextArea(activeMessage.contents, cellContentStyle);

				GUILayout.FlexibleSpace();

				GUILayout.BeginVertical();
				{
					GUILayout.BeginHorizontal();
					{
						GUILayout.FlexibleSpace();

						if (GUILayout.Button("Send Reply", cellOptionStyle))
						{
							cellState = MenuState.Response;
						}
					}
					GUILayout.EndHorizontal();
				}
				GUILayout.EndVertical();
			}
			else if (cellState == MenuState.Response)
			{
				// End the header.
				DoHeader("Select Response:");

				GUILayout.Space(24f);

				foreach (string response in activeMessage.responses)
				{
					if (GUILayout.Button("-> " + response, cellOptionStyle))
					{
						activeMessage.bResponded = true;

						cellState = MenuState.ResponseSent;

						// TODO: Store PLAYER IMPLICATION associated with selected response.
					}

					GUILayout.Space(5f);
				}
			}
			else if (cellState == MenuState.ResponseSent)
			{
				// End the header.
				DoHeader("Response sent.");

				// Player presses X to close the window.
			}

			GUILayout.EndArea();
		}
	}

	void DoHeader(string headerText)
	{
		GUILayout.BeginHorizontal();

		GUILayout.FlexibleSpace();
		if (GUILayout.Button("", cellCloseButtStyle))
		{
			bShowPhoneUI = false;
		}
		GUILayout.EndHorizontal();
		GUILayout.Space(16f);
		GUILayout.Label(headerText, cellContentStyle);
		GUILayout.Space(16f);
	}

	int NumUnreadMessages()
	{
		int unread = 0;
		foreach (CellMessage msg in messages)
		{
			if (msg.bUnread)
			{
				unread++;
			}
		}
		return unread;
	}

	public void ClosePhone()
	{
		bShowPhoneUI = false;
	}

	public void OpenPhone()
	{
		bShowPhoneUI = true;
		cellState = MenuState.MessageCount;
	}

	public bool IsOpen()
	{
		return bShowPhoneUI;
	}
}
