﻿using UnityEngine;
using System.Collections.Generic;

public class Inventory : MonoBehaviour
{
	public int totalValue = 0;

	List<ItemInfo> items = new List<ItemInfo>();

	public List<SpriteRenderer> slots = new List<SpriteRenderer>();

	public Transform valueTextLocation = null;

	public enum ItemSlot
	{
		None = -1,
		SockLeft,
		SockRight,
		ShoeLeft,
		ShoeRight,
		LegsUnder,
		LegsOver,
		ChestUnder,
		ChestOver,
		Cellphone,
		SLOTCOUNT,
	}

	void Start()
	{
		for (int i = 0; i < (int)ItemSlot.SLOTCOUNT; ++i)
		{
			items.Add(null);
		}
		
		gameObject.SetActive(false);
	}

	void OnGUI()
	{
		if (gameObject.activeSelf)
		{
			// Get location to draw UI.
			Vector3 loc = Camera.main.WorldToScreenPoint(valueTextLocation.position);

			GUIStyle textStyle = GameManager.MorningSkin.GetStyle("PanelText");

			textStyle.fontSize = (int)(((float)Screen.height * 0.25f) / 11f);

			// Who cares about width/height.  All we need is a line for now.
			GUILayout.BeginArea(new Rect(loc.x, Screen.height - loc.y, Screen.width, Screen.height));
			{
				Color oldColor = textStyle.normal.textColor;
				textStyle.normal.textColor = Color.white;
				GUILayout.Label("<b>Value:</b> $" + totalValue.ToString(), textStyle);
				textStyle.normal.textColor = oldColor;
			}
			GUILayout.EndArea();
		}
	}

	public void Show()
	{
		gameObject.SetActive(true);
	}

	public void Hide()
	{
		gameObject.SetActive(false);
	}

	public bool IsOpen()
	{
		return gameObject.activeSelf;
	}

	public bool AddItem(ItemInfo item)
	{
		bool bAdded = false;

		int slotIdx = (int)item.slot;

		if (item.slot != ItemSlot.None && items[slotIdx] == null)
		{
			items[slotIdx] = item;
			SpriteRenderer itemRenderer = item.GetComponent<SpriteRenderer>();
			slots[slotIdx].sprite = itemRenderer.sprite;
			slots[slotIdx].color = itemRenderer.color;

			itemRenderer.enabled = false;
			item.GetComponent<BoxCollider2D>().enabled = false;

			totalValue += item.value;

			bAdded = true;
		}

		return bAdded;
	}

	public ItemInfo GetItem(ItemSlot slot)
	{
		return slot != ItemSlot.None ? items[(int)slot] : null;
	}
}
