﻿using UnityEngine;
using System.Collections;

public class PlayerController : MonoBehaviour
{
	Animator animator = null;

	public float velocity = 2f;
	Vector2 moveDir = Vector2.zero;

	public InfoBox infoBox = null;
	bool bHasInfo = false;

	public GameObject infoNotification = null;

	public Inventory inventory = null;

	void Start()
	{
		animator = GetComponent<Animator>();
	}
	
	void Update()
	{
		Vector2 dir = Vector2.zero;

		dir.x = Input.GetAxisRaw("Horizontal");
		dir.y = Input.GetAxisRaw("Vertical");

		if (dir.magnitude == 0f)
		{
			animator.SetInteger("Direction", 0);
		}
		else
		{
			if (dir.x > 0)
			{
				animator.SetInteger("Direction", 2);
			}
			else if (dir.x < 0)
			{
				animator.SetInteger("Direction", 4);
			}
			else if (dir.y > 0)
			{
				animator.SetInteger("Direction", 1);
			}
			else if (dir.y < 0)
			{
				animator.SetInteger("Direction", 3);
			}
		}

		moveDir = dir;

		if (bHasInfo && Input.GetButtonDown("Jump"))
		{
			infoBox.bShowInfo = !infoBox.bShowInfo;
		}

		Cellphone phone = GetCellphone();
		if (Input.GetKeyDown(KeyCode.C) && phone != null)
		{
			if (phone.IsOpen())
			{
				phone.ClosePhone();
			}
			else
			{
				phone.OpenPhone();
			}
		}

		if (Input.GetKeyDown(KeyCode.I) && inventory != null)
		{
			if (inventory.IsOpen())
			{
				inventory.Hide();
			}
			else
			{
				inventory.Show();
			}
		}
	}

	public void ClearInfo()
	{
		bHasInfo = false;
		infoNotification.SetActive(false);
	}

	void FixedUpdate()
	{
		rigidbody2D.MovePosition(rigidbody2D.position + (moveDir.normalized * velocity * Time.fixedDeltaTime));
	}

	void OnTriggerEnter2D(Collider2D other)
	{
		ItemInfo info = other.GetComponent<ItemInfo>();
		if (info != null)
		{
			infoBox.item = info;
			bHasInfo = true;

			infoNotification.SetActive(true);
		}
	}

	void OnTriggerExit2D(Collider2D other)
	{
		ItemInfo info = other.GetComponent<ItemInfo>();
		if (info != null)
		{
			infoBox.item = null;
			infoBox.bShowInfo = false;
			bHasInfo = false;

			infoNotification.SetActive(false);
		}
	}

	Cellphone GetCellphone()
	{
		ItemInfo cellInfo = inventory.GetItem(Inventory.ItemSlot.Cellphone);
		return cellInfo != null ? cellInfo.GetComponent<Cellphone>() : null;
	}
}
